Struct cpu_stats
Source #[repr(C)]
pub struct cpu_stats {Show 17 fields
pub last_updated_instant: zx_instant_mono_t,
pub normalized_busy_time: zx_duration_mono_t,
pub idle_time: zx_duration_mono_t,
pub reschedules: ulong,
pub context_switches: ulong,
pub preempts: ulong,
pub yields: ulong,
pub interrupts: ulong,
pub timer_ints: ulong,
pub timers: ulong,
pub perf_ints: ulong,
pub syscalls: ulong,
pub page_faults: ulong,
pub reschedule_ipis: ulong,
pub generic_ipis: ulong,
pub active_energy_consumption_nj: ulong,
pub idle_energy_consumption_nj: ulong,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.