Struct guest_stats
Source #[repr(C)]
pub struct guest_stats {Show 14 fields
pub vm_entries: ulong,
pub vm_exits: ulong,
pub interrupts: ulong,
pub interrupt_windows: ulong,
pub cpuid_instructions: ulong,
pub hlt_instructions: ulong,
pub control_register_accesses: ulong,
pub io_instructions: ulong,
pub rdmsr_instructions: ulong,
pub wrmsr_instructions: ulong,
pub ept_violations: ulong,
pub xsetbv_instructions: ulong,
pub pause_instructions: ulong,
pub vmcall_instructions: ulong,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.