Struct percpu
Source #[repr(C, align(64))]
pub struct percpu {Show 17 fields
pub timer_queue: TimerQueue,
pub search_set: CpuSearchSet,
pub scheduler: Scheduler,
pub active_cl_transaction: *mut ChainLockTransaction,
pub chain_lock_conflict_id: __BindgenOpaqueArray8<[u8; 8]>,
pub gstats: guest_stats,
pub stats: cpu_stats,
pub __bindgen_padding_0: [u8; 8],
pub idle_power_thread: IdlePowerThread,
pub counters: *mut i64,
pub dpc_runner: DpcRunner,
pub vm_page_counts: vm_page_counts_t,
pub lockup_detector_timer: Timer,
pub sampling_timer: Timer,
pub memory_stall_accumulator: StallAccumulator,
pub resume_state: PlatformCpuResumeState,
pub __bindgen_padding_1: [u8; 7],
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.